@@ -97,7 +97,7 @@ pub enum ClassicELBScheme {
 
 /// Subnets is a slice of Subnet.
 #[derive(Clone, Debug, Default, Serialize, Deserialize)]
-pub struct Subnets(Vec<SubnetSpec>);
+pub struct Subnets(pub Vec<SubnetSpec>);
 
 /// SubnetSpec configures an AWS Subnet.
 #[derive(Clone, Debug, Default, Serialize, Deserialize)]
